# File: DescriptivePlotsData.R (19/12/2017)
# Coded by: Mathieu Ribatet
#
# Reference:
# Ben Salah, H., De Gooijer, J.G., Gaunnoun, A., and Ribatet, M. 
#   "Mean-variance and mean-semivariance portfolio selection: A
#    multivariate nonparametric approach".
# Accepted for publication in: Financial Markets and Portfolio Management 
##########################################################################


rm(list=ls())
library(chron)
library(ggplot2)
library(reshape2)
source("OptimalAllocation.R")
source("utils.R")

data <- read.table("donnees.csv", header = TRUE, sep = ";", dec = ",")
date <- as.Date(data[,1], "%d/%m/%y")

## Remove the date column
data <- data[,-1]

## Keep only the asset which have enough data
asset.removed <- c("Credit.Agricole", "Legrand", "Nokia")
data <- data[,!(names(data) %in% asset.removed)]

## Remove the missing values
## Get the corresponding date
f <- function(x)
    any(is.na(x))

idx.na <- apply(data, 1, f)

data <- data[!idx.na,]
date <- date[!idx.na]

## Revert the data so that it starts with the oldest data
data <- data[nrow(data):1,]
date <- rev(date)


## Work with percentages
data <- 100 * data

## Retrieve the CAC 40
CAC40 <- data[,"CAC40"]
data <- data[,which(names(data) != "CAC40")]

## Do a plot of the CAC40 and highlight calm, good and crisis periods
profit <- function(x)
    cumprod(1 + x / 100)

crisis <- as.Date(c("01/01/08", "31/03/09"), "%d/%m/%y")
calm <- as.Date(c("01/01/04", "31/03/05"), "%d/%m/%y")
good <- as.Date(c("01/01/13", "31/03/14"), "%d/%m/%y")

df <- data.frame(Date = date, CAC40 = 6464.12 * profit(CAC40))
df2 <- data.frame(Date = crisis, value = max(df$CAC40))
df3 <- data.frame(Date = calm, value = max(df$CAC40))
df4 <- data.frame(Date = good, value = max(df$CAC40))

plotCAC40 <- ggplot(df, aes(Date)) + ylab("CAC 40") +
    geom_area(data = df2, aes(x = Date, y = value), fill = "red", alpha = 0.5) +
    geom_area(data = df3, aes(x = Date, y = value), fill = "green", alpha = 0.5) +
    geom_area(data = df4, aes(x = Date, y = value), fill = "blue", alpha = 0.5) +
    geom_line(aes(y = CAC40))

plotCAC40
